@@ -4,7 +4,7 @@ from pathlib import Path
 import time
 
 from influx_line_protocol import Metric
-
+import requests
 #
 # METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "/var/log/wf_metrics"))
 #
@@ -27,19 +27,32 @@ from influx_line_protocol import Metric
 #     for value in values:
 #         metric.add_value(value, values[value])
 #     metlogger.info(metric)
+#
+#
+# @lru_cache(maxsize=2)
+# def get_metrics_pipe():
+#     METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "/var/log/wf_metrics"))
+#     if not METRICS_LOG_DIR.exists():
+#         METRICS_LOG_DIR.mkdir()
+#     path = METRICS_LOG_DIR / f"{os.environ.get('METRICS_NAME', 'control-uploader')}"
+#     if not path.exists():
+#         os.mkfifo(path, 0o777)
+#     return path
+#
+# def emit(name, values, tags=None):
+#     path = get_metrics_pipe()
+#     with open(path, 'w') as metrics_pipe:
+#         metric = Metric(name)
+#         metric.with_timestamp(time.time() * 1000000000)
+#         if tags is None:
+#             tags = {"tag": "team"}
+#         for tag in tags:
+#             metric.add_tag(tag, tags[tag])
+#         for value in values:
+#             metric.add_value(value, values[value])
+#         metrics_pipe.write(str(metric))
 
 
-@lru_cache(maxsize=2)
-def get_metrics_pipe():
-    METRICS_LOG_DIR = Path(os.environ.get("METRICS_LOG", "/var/log/wf_metrics"))
-    if not METRICS_LOG_DIR.exists():
-        METRICS_LOG_DIR.mkdir()
-    path = METRICS_LOG_DIR / f"{os.environ.get('METRICS_NAME', 'control-uploader')}"
-    if not path.exists():
-        os.mkfifo(path, 0o777)
-    metrics_pipe = open(path, 'w')
-    return metrics_pipe
-
 def emit(name, values, tags=None):
     metric = Metric(name)
     metric.with_timestamp(time.time() * 1000000000)
@@ -49,4 +62,4 @@ def emit(name, values, tags=None):
         metric.add_tag(tag, tags[tag])
     for value in values:
         metric.add_value(value, values[value])
-    get_metrics_pipe().write(str(metric))
+    requests.post("http://localhost:8080/telegraf", data=str(metric).encode("utf8"))
